@@ -1,5 +1,5 @@
 #
-# Copyright 2018-2020 IBM Corporation
+# Copyright 2018-2021 Elyra Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@ import errno
 import io
 import json
 import os
+import tornado
 
 from jsonschema import ValidationError
 from elyra.metadata import METADATA_TEST_NAMESPACE, Metadata, MetadataStore, FileMetadataStore, \
@@ -78,6 +79,18 @@ valid_display_name_json = {
     }
 }
 
+
+invalid_schema_name_json = {
+    'schema_name': 'metadata-testxxx',
+    'display_name': 'invalid schema name',
+    'metadata': {
+        'uri_test': 'http://localhost:31823/v1/models?version=2017-02-13',
+        'number_range_test': 8,
+        'required_test': "required_value"
+    }
+}
+
+
 # Contains all values corresponding to test schema...
 complete_metadata_json = {
     "schema_name": "metadata-test",
@@ -149,10 +162,10 @@ def create_instance(metadata_store: MetadataStore, location: str, name: str, con
         else:
             create_file(location, name + '.json', content)
     elif isinstance(metadata_store, MockMetadataStore):
-        instances = getattr(metadata_store, 'instances')
+        instances = metadata_store.instances
         if instances is None:
             setattr(metadata_store, 'instances', dict())
-            instances = getattr(metadata_store, 'instances')
+            instances = metadata_store.instances
         if not isinstance(content, dict):
             content = {'display_name': name, 'reason': "JSON failed to load for instance '{}'".format(name)}
         instances[name] = content
@@ -177,6 +190,28 @@ def get_instance(instances, field, value):
     assert False, "Value '{}' for field '{}' was not found in instances!".format(value, field)
 
 
+def expected_http_error(error, expected_code, expected_message=None):
+    """Check that the error matches the expected output error."""
+    e = error.value
+    if isinstance(e, tornado.web.HTTPError):
+        if expected_code != e.status_code:
+            return False
+        if expected_message is not None and expected_message != str(e):
+            return False
+        return True
+    elif any([
+        isinstance(e, tornado.httpclient.HTTPClientError),
+        isinstance(e, tornado.httpclient.HTTPError)
+    ]):
+        if expected_code != e.code:
+            return False
+        if expected_message:
+            message = json.loads(e.response.body.decode())['message']
+            if expected_message != message:
+                return False
+        return True
+
+
 class PropertyTester(object):
     """Helper class used by elyra_md tests to test each of the properties in the test.json schema. """
     name = None             # prefixed with 'test_' is test name, post-fixed with '_test' is schema property name
