@@ -35,9 +35,10 @@ def pipeline():
     return PipelineParser.parse(pipeline_resource)
 
 
-def test_fail_get_runtime_configuration(processor):
+def test_fail_get_metadata_configuration_invalid_namespace(processor):
     with pytest.raises(RuntimeError):
-        processor._get_runtime_configuration('non_existent_metadata')
+        processor._get_metadata_configuration(namespace="non_existent_namespace",
+                                              name='non_existent_metadata')
 
 
 def test_generate_dependency_archive(processor):
@@ -47,6 +48,7 @@ def test_generate_dependency_archive(processor):
     test_operation = Op(id='123e4567-e89b-12d3-a456-426614174000',
                         type='execution-node',
                         classifier='kfp',
+                        name='test',
                         filename=pipelines_test_file,
                         dependencies=pipeline_dependencies,
                         runtime_image='tensorflow/tensorflow:latest')
@@ -70,6 +72,7 @@ def test_fail_generate_dependency_archive(processor):
     test_operation = Op(id='123e4567-e89b-12d3-a456-426614174000',
                         type='execution-node',
                         classifier='kfp',
+                        name='test',
                         filename=pipelines_test_file,
                         dependencies=pipeline_dependencies,
                         runtime_image='tensorflow/tensorflow:latest')
@@ -86,6 +89,7 @@ def test_get_dependency_source_dir(processor):
     test_operation = Op(id='123e4567-e89b-12d3-a456-426614174000',
                         type='execution-node',
                         classifier='kfp',
+                        name='test',
                         filename=pipelines_test_file,
                         runtime_image='tensorflow/tensorflow:latest')
 
@@ -101,6 +105,7 @@ def test_get_dependency_archive_name(processor):
     test_operation = Op(id='this-is-a-test-id',
                         type='execution-node',
                         classifier='kfp',
+                        name='test',
                         filename=pipelines_test_file,
                         runtime_image='tensorflow/tensorflow:latest')
 
