@@ -1,5 +1,5 @@
 #
-# Copyright 2018-2020 IBM Corporation
+# Copyright 2018-2021 Elyra Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -70,7 +70,8 @@ class NodeBase(object):
 
         self.env_vars = []
         if self.fail:  # NODE_FILENAME is required, so skip if triggering failure
-            os.environ.pop("NODE_FILENAME")  # remove entry that might already be present
+            if "NODE_FILENAME" in os.environ:  # remove entry if present
+                os.environ.pop("NODE_FILENAME")
         else:
             self.env_vars.append(f"NODE_FILENAME={self.filename}")
         if self.inputs:
@@ -78,7 +79,7 @@ class NodeBase(object):
         if self.outputs:
             self.env_vars.append(f"OUTPUT_FILENAMES={';'.join(self.outputs)}")
 
-        return Operation(self.id, 'execution_node', self.classifier, self.filename, self.image_name or "NA",
+        return Operation(self.id, 'execution_node', self.name, self.classifier, self.filename, self.image_name or "NA",
                          dependencies=self.dependencies, env_vars=self.env_vars,
                          inputs=self.inputs, outputs=self.outputs,
                          parent_operations=self.parent_operations)
